@@ -24,46 +24,46 @@ class XControl():
     self.d = Xtst.XOpenDisplay(None)
 
   # Generate a keypress, given the keyname.
-  def SendKey(self, key):
+  def sendKey(self, key):
     sym = Xlib.XStringToKeysym(key)
     code = Xlib.XKeysymToKeycode(self.d, sym)
     Xtst.XTestFakeKeyEvent(self.d, code, True, 0)
     Xtst.XTestFakeKeyEvent(self.d, code, False, 0)
     Xlib.XFlush(self.d)
 
-  def SendKeyDown(self, key):
+  def sendKeyDown(self, key):
     sym = Xlib.XStringToKeysym(key)
     code = Xlib.XKeysymToKeycode(self.d, sym)
     Xtst.XTestFakeKeyEvent(self.d, code, True, 0)
     Xlib.XFlush(self.d)
 
-  def SendKeyUp(self, key):
+  def sendKeyUp(self, key):
     sym = Xlib.XStringToKeysym(key)
     code = Xlib.XKeysymToKeycode(self.d, sym)
     Xtst.XTestFakeKeyEvent(self.d, code, False, 0)
     Xlib.XFlush(self.d)
 
-  def SendCtrlKey(self, key):
-    self.SendKeyDown("Control_R")
-    self.SendKey(key)
-    self.SendKeyUp("Control_R")
+  def sendCtrlKey(self, key):
+    self.sendKeyDown("Control_R")
+    self.sendKey(key)
+    self.sendKeyUp("Control_R")
 
   # Move the mouse to the given (absolute) coordinates
-  def MouseMove(self, x, y):
+  def mouseMove(self, x, y):
     Xtst.XTestFakeMotionEvent(self.d, -1, x, y, 0);
     Xlib.XFlush(self.d)
 
-  def MouseMoveRelative(self, x, y):
+  def mouseMoveRelative(self, x, y):
     Xtst.XTestFakeRelativeMotionEvent(self.d, -1, x, y, 0);
     Xlib.XFlush(self.d)
 
   # Click a mouse button (1:left, 2:right)
-  def MouseClick(self, button):
+  def mouseClick(self, button):
     Xtst.XTestFakeButtonEvent( self.d, button, True, 0 );
     Xtst.XTestFakeButtonEvent( self.d, button, False, 0 );
     Xlib.XFlush(self.d)
 
-  def StylusTap(self, x, y):
+  def stylusTap(self, x, y):
     Xtst.XTestFakeMotionEvent(self.d, -1, x, y, 0)
     Xtst.XTestFakeButtonEvent(self.d, 1, True, 0 );
     Xtst.XTestFakeButtonEvent(self.d, 1, False, 0 );
@@ -76,32 +76,33 @@ class XControl():
 #   "b button" -> MouseClick(button)
 #   "t x y"    -> StylusTap(x,y)
 #   "s time"   -> sleep(time)
-  def ExecuteScript(self, script):
+  def executeScript(self, script):
     for c in script:
       cmd=c.split()
       if cmd[0]=='k':
         aux=cmd[1].split('-')
         if len(aux)==1:
-          self.SendKey(cmd[1])
+          self.sendKey(cmd[1])
         else:
-          self.SendCtrlKey(aux[1])
+          self.sendCtrlKey(aux[1])
       elif cmd[0]=='a':
-        self.SendKeyDown(cmd[1])              
+        self.sendKeyDown(cmd[1])              
       elif cmd[0]=='b':
-        self.MouseClick(int(cmd[1]))
+        self.mouseClick(int(cmd[1]))
       elif cmd[0]=='m':
-        self.MouseMove(int(cmd[1]), int(cmd[2]))
+        self.mouseMove(int(cmd[1]), int(cmd[2]))
       elif cmd[0]=='r':
-        self.MouseMoveRelative(int(cmd[1]), int(cmd[2]))
+        self.mouseMoveRelative(int(cmd[1]), int(cmd[2]))
       elif cmd[0]=='t':
-        self.StylusTap(int(cmd[1]), int(cmd[2]))
+        self.stylusTap(int(cmd[1]), int(cmd[2]))
       elif cmd[0]=='s':
         sleep(float(cmd[1]))
       else: break
 
-  def ExecuteReleasedScript(self, script):
+  def executeReleasedScript(self, script):
     for c in script:
       cmd=c.split()  
       if cmd[0]=='a':
-        self.SendKeyUp(cmd[1])
+        self.sendKeyUp(cmd[1])
       else: break
+
